==> gnuastro-0.10.tar.gz: gnuastro-0.10/tests/convertt/fitstojpegcmyk.sh <==
# Convert a FITS image into a JPEG file.
#
# See the Tests subsection of the manual for a complete explanation
# (in the Installing gnuastro section).
#
# Original author:
#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
# Contributing author(s):
# Copyright (C) 2015-2019 Free Software Foundation, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.





# Preliminaries
# =============
#
# Set the variables (The executable is in the build tree). Do the
# basic checks to see if the executable is made or if the defaults
# file exists (basicchecks.sh is in the source tree).
img=psf.fits
prog=convertt
execname=../bin/$prog/ast$prog





# Skip?
# =====
#
# If the dependencies of the test don't exist, then skip it. There are two
# types of dependencies:
#
#   - The executable was not made (for example due to a configure option),
#
#   - The input data was not made (for example the test that created the
#     data file failed).
#
#   - libjpeg was not present on the system.
if [ ! -f $execname           ];then echo "$execname not created.";exit 77;fi
if [ ! -f $img                ];then echo "$img does not exist.";  exit 77;fi
if [ "x$haslibjpeg" != "xyes" ];then echo "libjpeg not present.";  exit 77;fi





# Actual test script
# ==================
#
# `check_with_program' can be something like `Valgrind' or an empty
# string. Such programs will execute the command if present and help in
# debugging when the developer doesn't have access to the user's system.
$check_with_program $execname blank blank blank $img --output=f2jcmyk.jpg

==> gnuastro-0.18.tar.gz: gnuastro-0.18/tests/convertt/fitstojpegcmyk.sh <==
# Convert a FITS image into a JPEG file.
#
# See the Tests subsection of the manual for a complete explanation
# (in the Installing gnuastro section).
#
# Original author:
#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
# Contributing author(s):
# Copyright (C) 2015-2022 Free Software Foundation, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.





# Preliminaries
# =============
#
# Set the variables (The executable is in the build tree). Do the
# basic checks to see if the executable is made or if the defaults
# file exists (basicchecks.sh is in the source tree).
img=psf.fits
prog=convertt
execname=../bin/$prog/ast$prog





# Skip?
# =====
#
# If the dependencies of the test don't exist, then skip it. There are two
# types of dependencies:
#
#   - The executable was not made (for example due to a configure option),
#
#   - The input data was not made (for example the test that created the
#     data file failed).
#
#   - libjpeg was not present on the system.
if [ ! -f $execname           ];then echo "$execname not created.";exit 77;fi
if [ ! -f $img                ];then echo "$img does not exist.";  exit 77;fi
if [ "x$haslibjpeg" != "xyes" ];then echo "libjpeg not present.";  exit 77;fi





# Actual test script
# ==================
#
# 'check_with_program' can be something like Valgrind or an empty
# string. Such programs will execute the command if present and help in
# debugging when the developer doesn't have access to the user's system.
$check_with_program $execname blank blank blank $img --output=f2jcmyk.jpg
